==> hyades.source_1.2.2_20040226_1349.zip: org/eclipse/hyades/execution/recorder/http/HttpRecorderPlugin.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.execution.recorder.http;

import java.util.MissingResourceException;
import java.util.ResourceBundle;

import org.eclipse.core.runtime.IPluginDescriptor;
import org.eclipse.hyades.execution.recorder.http.local.HttpRecorderAgentEnvironmentAdapter;
import org.eclipse.hyades.execution.recorder.http.local.HttpRecorderDataProcessor;
import org.eclipse.hyades.execution.recorder.http.local.HttpRecorderExecutableObjectAdapter;
import org.eclipse.hyades.internal.execution.recorder.Recorder;
import org.eclipse.hyades.internal.execution.recorder.RecorderException;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.ui.plugin.AbstractUIPlugin;


/**
 * The main class of the Recorder Harness
 * @author Ernest Jessee
 */
public class HttpRecorderPlugin extends AbstractUIPlugin
{
	
	public static final String RECORDING_PATH = "recording_path"; //$NON-NLS-1$
	public static final String RECORDER_APP_ADAPTER="application_under_test"; //$NON-NLS-1$
	public static final String TEST_GENERATOR="default_test_generator"; //$NON-NLS-1$
	public static final String PROXY_PORT="default_proxy_port"; //$NON-NLS-1$
		
	private static HttpRecorderPlugin plugin;
	
	/**
	 * Stores a preference in the plugins preference store with the specified key and value 
	 * @param String key
	 * @param String value
	 */
	public static void storePreference(String key, String value)
	{
		getDefault().getPreferenceStore().setValue(key,value);
	}
	/**
	 *The plugins resourceBundle
	 */
	protected ResourceBundle resourceBundle;
	private Recorder recorder;

	/**
	 * Returns the plugin's resource bundle,
	 */
	private ResourceBundle getResourceBundle()
	{
		return resourceBundle;
	}
	
	/**
	 * returns resource String from this plugin's resource bundle
	 * @param String key
	 * @return String
	 */
	public static String getResourceString(String key)
	{
		return HttpRecorderPlugin.getDefault().getResourceBundle().getString(key);
	}
	
	/**
	 * acquires a reference to a plugin preference specified by "key"
	 * @param key
	 * @return
	 */
	public static String getPreference(String key)
	{
		return getDefault().getPreferenceStore().getString(key);
	}
	
	/**
	 * acquires a reference to a plugin preference specified by "key"
	 * @param key
	 * @return
	 */
	public static boolean getBoolPreference(String key)
	{
		return getDefault().getPreferenceStore().getBoolean(key);
	}
	
		
	/**
	 * The constructor.
	 */
	public HttpRecorderPlugin(IPluginDescriptor descriptor)
	{
		super(descriptor);
		plugin = this;
			
		try
		{
			recorder = new Recorder("org.eclipse.hyades.execution.recorder.http", //$NON-NLS-1$
									new HttpRecorderDataProcessor(),
									new HttpRecorderAgentEnvironmentAdapter(),
									new HttpRecorderExecutableObjectAdapter());
		}
		catch (RecorderException e1)
		{
			e1.printStackTrace();
		}
			
				
		
		try {
			resourceBundle= ResourceBundle.getBundle("org.eclipse.hyades.execution.recorder.http.HttpRecorderPlugin"); //$NON-NLS-1$
		} catch (MissingResourceException x) {
			resourceBundle = null;
		}
		
		initializeDefaultPreferences(getPreferenceStore());
	}

	/**
	 * Returns the shared instance.
	 */
	public static HttpRecorderPlugin getDefault() {
		return plugin;
	}
	
	
	
	/**
	 * @return
	 */
	public Recorder getRecorder()
	{
		return recorder;
	}

	/**
	 * @see org.eclipse.ui.plugin.AbstractUIPlugin#initializeDefaultPreferences(org.eclipse.jface.preference.IPreferenceStore)
	 */
	protected void initializeDefaultPreferences(IPreferenceStore store)
	{	
		store.setDefault(HttpRecorderPlugin.RECORDER_APP_ADAPTER,"org.eclipse.hyades.execution.recorder.RecorderApplication.InternetExplorer");		                                                           //$NON-NLS-1$
		store.setDefault(HttpRecorderPlugin.TEST_GENERATOR,"org.eclipse.hyades.execution.testgen.TestGenGenerator.HTTPGenerator"); //$NON-NLS-1$
		store.setDefault(HttpRecorderPlugin.PROXY_PORT,"450");		 //$NON-NLS-1$
		
	}

}

==> hyades.source_1.3.0_20040422_2239.zip: org/eclipse/hyades/execution/recorder/http/HttpRecorderPlugin.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.execution.recorder.http;

import java.util.ResourceBundle;

import org.eclipse.core.runtime.IPluginDescriptor;
import org.eclipse.hyades.execution.recorder.http.local.HttpRecorderAgentEnvironmentAdapter;
import org.eclipse.hyades.execution.recorder.http.local.HttpRecorderDataProcessor;
import org.eclipse.hyades.execution.recorder.http.local.HttpRecorderExecutableObjectAdapter;
import org.eclipse.hyades.execution.testgen.TestgenPlugin;
import org.eclipse.hyades.internal.execution.recorder.Recorder;
import org.eclipse.hyades.internal.execution.recorder.RecorderException;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.ui.plugin.AbstractUIPlugin;


/**
 * The main class of the Recorder Harness
 * @author Ernest Jessee
 */
public class HttpRecorderPlugin extends AbstractUIPlugin
{
	
	public static final String RECORDING_PATH = "recording_path"; //$NON-NLS-1$
	public static final String RECORDER_APP_ADAPTER="application_under_test"; //$NON-NLS-1$
	
	public static final String PROXY_PORT="default_proxy_port"; //$NON-NLS-1$

	public static final String DEFAULT_PORT="1080";		
	private static HttpRecorderPlugin plugin;
	
	/**
	 * Stores a preference in the plugins preference store with the specified key and value 
	 * @param String key
	 * @param String value
	 */
	public static void storePreference(String key, String value)
	{
		getDefault().getPreferenceStore().setValue(key,value);
	}

	private Recorder recorder;

	/**
	 * Returns the plugin's resource bundle,
	 */
	private ResourceBundle getResourceBundle()
	{
		return getDescriptor().getResourceBundle();
	}
	
	/**
	 * returns resource String from this plugin's resource bundle
	 * @param String key
	 * @return String
	 */
	public static String getResourceString(String key)
	{
		return HttpRecorderPlugin.getDefault().getResourceBundle().getString(key);
	}
	
	/**
	 * acquires a reference to a plugin preference specified by "key"
	 * @param key
	 * @return
	 */
	public static String getPreference(String key)
	{
		return getDefault().getPreferenceStore().getString(key);
	}
	
	/**
	 * acquires a reference to a plugin preference specified by "key"
	 * @param key
	 * @return
	 */
	public static boolean getBoolPreference(String key)
	{
		return getDefault().getPreferenceStore().getBoolean(key);
	}
	
		
	/**
	 * The constructor.
	 */
	public HttpRecorderPlugin(IPluginDescriptor descriptor)
	{
		super(descriptor);
		plugin = this;
			
		try
		{
			recorder = new Recorder("org.eclipse.hyades.execution.recorder.http", //$NON-NLS-1$
									new HttpRecorderDataProcessor(),
									new HttpRecorderAgentEnvironmentAdapter(),
									new HttpRecorderExecutableObjectAdapter());
		}
		catch (RecorderException e1)
		{
			e1.printStackTrace();
		}
				
		initializeDefaultPreferences(getPreferenceStore());
	}

	/**
	 * Returns the shared instance.
	 */
	public static HttpRecorderPlugin getDefault() {
		return plugin;
	}
	
	
	
	/**
	 * @return
	 */
	public Recorder getRecorder()
	{
		return recorder;
	}

	/**
	 * @see org.eclipse.ui.plugin.AbstractUIPlugin#initializeDefaultPreferences(org.eclipse.jface.preference.IPreferenceStore)
	 */
	protected void initializeDefaultPreferences(IPreferenceStore store)
	{	
		store.setDefault(HttpRecorderPlugin.RECORDER_APP_ADAPTER,"org.eclipse.hyades.execution.recorder.RecorderApplication.InternetExplorer");		                                                           //$NON-NLS-1$
		TestgenPlugin.getDefault().getPreferenceStore().setDefault(TestgenPlugin.TEST_GENERATOR,TestgenPlugin.getDefault().getDefaultGeneratorID());		
		store.setDefault(HttpRecorderPlugin.PROXY_PORT,DEFAULT_PORT);		 //$NON-NLS-1$
		
	}

}
